@@ -6,23 +6,22 @@ Copyright:
 This code and affiliated files are (C) by Bert Constantin and individual contributors.
 Please see LICENSE and AUTHORS for more information.
 """
+from __future__ import absolute_import
 import django
-from polymorphic_model import PolymorphicModel
-from manager import PolymorphicManager
-from query import PolymorphicQuerySet
-from query_translate import translate_polymorphic_Q_object
-from showfields import ShowFieldContent, ShowFieldType, ShowFieldTypeAndContent
-from showfields import ShowFields, ShowFieldTypes, ShowFieldsAndTypes  # import old names for compatibility
+from .polymorphic_model import PolymorphicModel
+from .manager import PolymorphicManager
+from .query import PolymorphicQuerySet
+from .query_translate import translate_polymorphic_Q_object
+from .showfields import ShowFieldContent, ShowFieldType, ShowFieldTypeAndContent
+from .showfields import ShowFields, ShowFieldTypes, ShowFieldsAndTypes  # import old names for compatibility
 
 
 # Monkey-patch Django < 1.5 to allow ContentTypes for proxy models.
-if django.VERSION[:2] < (1, 5): 
+if django.VERSION[:2] < (1, 5):
     from django.contrib.contenttypes.models import ContentTypeManager
-    from django.utils.encoding import smart_unicode
+    from django.utils.encoding import smart_text
 
     def get_for_model(self, model, for_concrete_model=True):
-        from django.utils.encoding import smart_unicode
-
         if for_concrete_model:
             model = model._meta.concrete_model
         elif model._deferred:
@@ -36,7 +35,7 @@ if django.VERSION[:2] < (1, 5):
             ct, created = self.get_or_create(
                 app_label = opts.app_label,
                 model = opts.object_name.lower(),
-                defaults = {'name': smart_unicode(opts.verbose_name_raw)},
+                defaults = {'name': smart_text(opts.verbose_name_raw)},
             )
             self._add_to_cache(self.db, ct)
 
